## Summary

This package uses GROBID to create annotated TEI documents from PDFs (see [example](https://github.com/CoLRev-Environment/colrev/blob/main/tests/data/WagnerLukyanenkoParEtAl2022.tei.xml)).

Running GROBID requires Docker.

## pdf-prep

This package can be added to a project using the following command:

```
colrev pdf-prep -a colrev.grobid_tei
```

## Links

![grobidactivity](https://img.shields.io/github/commit-activity/y/kermitt2/grobid?color=green&style=plastic)

- [GRBOBID](https://github.com/kermitt2/grobid): parsing annotated PDF content (License: [Apache 2.0](https://github.com/kermitt2/grobid/blob/master/LICENSE))
